# Generated by Django 4.0.4 on 2022-05-18 12:31

import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks
from django.db import migrations
from wagtail.blocks.stream_block import StreamValue


def plain_to_structured(block):
    person = {
        "person": block["value"]["person"],
        "position": "",
    }

    block["value"]["person"] = person

    return block


def structured_to_plain(block):
    block["value"]["person"] = block["value"]["person"]["person"]

    return block


def get_content(page, mapper):
    stream_data = []
    mapped = False

    for block in page.content.raw_data:
        if (
            block["type"] == "static_program_block"
            or block["type"] == "redmine_program_block"
        ):
            stream_data.append(mapper(block))
            mapped = True

        else:
            stream_data.append(block)

    return stream_data, mapped


def migrate(apps, mapper):
    DistrictProgramPage = apps.get_model("district", "DistrictProgramPage")

    for page in DistrictProgramPage.objects.all():
        content, mapped = get_content(page, mapper)

        if mapped:
            page.content = StreamValue(page.content, content, is_lazy=True)
            page.save()


def forwards(apps, schema_editor):
    migrate(apps, plain_to_structured)


def backwards(apps, schema_editor):
    migrate(apps, structured_to_plain)


class Migration(migrations.Migration):
    dependencies = [
        ("district", "0071_alter_districthomepage_options_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="districtprogrampage",
            name="content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "static_program_block",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "headline",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek bloku", required=True
                                    ),
                                ),
                                (
                                    "perex",
                                    wagtail.blocks.TextBlock(
                                        label="Krátký text pod nadpisem", required=True
                                    ),
                                ),
                                (
                                    "person",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "person",
                                                wagtail.blocks.PageChooserBlock(
                                                    label="Osoba",
                                                    page_type=[
                                                        "district.DistrictPersonPage"
                                                    ],
                                                ),
                                            ),
                                            (
                                                "position",
                                                wagtail.blocks.CharBlock(
                                                    label="Pozice", required=False
                                                ),
                                            ),
                                        ]
                                    ),
                                ),
                                (
                                    "completion_percentage",
                                    wagtail.blocks.IntegerBlock(
                                        label="Procento dokončení", required=True
                                    ),
                                ),
                                (
                                    "program_items",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "title",
                                                    wagtail.blocks.CharBlock(
                                                        label="Název", required=True
                                                    ),
                                                ),
                                                (
                                                    "completion_percentage",
                                                    wagtail.blocks.IntegerBlock(
                                                        label="Procento dokončení",
                                                        required=True,
                                                    ),
                                                ),
                                                (
                                                    "issue_link",
                                                    wagtail.blocks.URLBlock(
                                                        label="Odkaz na Redmine issue",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Seznam bodů",
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "redmine_program_block",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "headline",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek bloku", required=True
                                    ),
                                ),
                                (
                                    "perex",
                                    wagtail.blocks.TextBlock(
                                        label="Krátký text pod nadpisem", required=True
                                    ),
                                ),
                                (
                                    "person",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "person",
                                                wagtail.blocks.PageChooserBlock(
                                                    label="Osoba",
                                                    page_type=[
                                                        "district.DistrictPersonPage"
                                                    ],
                                                ),
                                            ),
                                            (
                                                "position",
                                                wagtail.blocks.CharBlock(
                                                    label="Pozice", required=False
                                                ),
                                            ),
                                        ]
                                    ),
                                ),
                                (
                                    "redmine_issue",
                                    wagtail.blocks.IntegerBlock(
                                        label="Číslo Redmine issue", required=True
                                    ),
                                ),
                                (
                                    "completion_percentage",
                                    wagtail.blocks.IntegerBlock(
                                        help_text="Hodnota se automaticky načte s Redmine",
                                        label="Procento dokončení - bude doplněno automaticky",
                                        required=False,
                                    ),
                                ),
                                (
                                    "program_items",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "title",
                                                    wagtail.blocks.CharBlock(
                                                        label="Název", required=True
                                                    ),
                                                ),
                                                (
                                                    "completion_percentage",
                                                    wagtail.blocks.IntegerBlock(
                                                        label="Procento dokončení",
                                                        required=True,
                                                    ),
                                                ),
                                                (
                                                    "issue_link",
                                                    wagtail.blocks.URLBlock(
                                                        label="Odkaz na Redmine issue",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        help_text="Hodnota se automaticky načte s Redmine",
                                        label="Seznam bodů - bude doplněno automaticky",
                                        required=False,
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="obsah stránky",
            ),
        ),
        migrations.RunPython(forwards, backwards),
    ]
